//
//  YHPreviewViewModel.swift
//  galaxy
//
//  Created by davidhuangA on 2024/3/3.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHPreviewViewModel: YHBaseViewModel {
    //家庭成员信息 预览
    var familyInfoPreviewModel : YHFamilyMemberGroupInfo?
    var arrDataForFamilyInfo : [YHPreviewInfoSessionModel] = [] //用于展示
    var arrDataForParents : [YHPreviewInfoSessionModel] = []//父亲
    var arrDataForSpouse : [YHPreviewInfoSessionModel] = []//配偶
    var arrDataForChildren : [YHPreviewInfoSessionModel] = []//子女
    var arrDataForBrother : [YHPreviewInfoSessionModel] = []//兄弟姐妹
    
    
    //主申请人信息 预览 - 未完成
    var mainApplicationInfoPreviewModel : YHMainInformationModel?
    var arrDataForMainApplicationInfo : [YHPreviewInfoSessionModel] = []
    
    //其他信息 预览
    private var otherInfoPreviewModel : YHPreviewForOtherInfoModel?
    var arrDataForOtherInfo : [YHPreviewInfoSessionModel] = []
    
    //基本资料 预览
    private var basiceInfoPreviewModel : YHBasicInfoFillModel?
    var arrDataForBasicInfo : [YHPreviewInfoSessionModel] = []
}

extension YHPreviewViewModel {
    //获取家庭成员 预览数据
    func getPreviewForFamilyInfo(params:[String:Any], callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Preview.previewFamilyInfoApi
        let _ = YHNetRequest.getRequest(url: strUrl, params:params) {[weak self] json, code in
            YHHUD.hide()
            
            guard let self = self else { return }
            printLog("model 是 ==> \(json)")
            
            if json.code == 200 {
                let dic = json.data as? [AnyHashable : Any]
                guard let resultModel = YHFamilyMemberGroupInfo.deserialize(dict: dic) else {
                    let error = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    callBackBlock(false,error)
                    return
                }
                familyInfoPreviewModel = resultModel
                installDataForFamilyInfo()
                callBackBlock(true,nil)
            } else {
                let error = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg)
                callBackBlock(false,error)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
    //获取主申请人 预览数据
    func getPreviewForMainApplicationInfo( params:[String : Any],callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Preview.previewMainApplicationInfoApi
        let _ = YHNetRequest.getRequest(url: strUrl,params: params) { [weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            if json.code == 200 {
                let dic = json.data
                guard let result = YHMainInformationModel.deserialize(from: dic as? Dictionary) else {
                    callBackBlock(false,nil)
                    return
                }
                self.mainApplicationInfoPreviewModel = result
                installDataForMainApplicationInfo()
                callBackBlock(true, nil)
            } else {
                installDataForMainApplicationInfo() //for test hjl
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code), errorMsg: json.msg)
                callBackBlock(false, error)
            }
        } failBlock: { err in
            self.installDataForMainApplicationInfo()//for test hjl
            callBackBlock(false,err)
        }
    }
    
    
    //获取基本资料预览 数据
    func getPreviewForBasicInfo( params:[String : Any],callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Preview.previewBasicInfoApi
        
        let _ = YHNetRequest.getRequest(url: strUrl,params: params) { [weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            printLog("model 是 ==> \(json)")
            
            if json.code == 200 {
                let dic = json.data
                guard let resultModel = YHBasicInfoFillModel.deserialize(dict: dic as? [AnyHashable : Any]) else {
                    callBackBlock(false,nil)
                    return
                }
                
                self.basiceInfoPreviewModel = resultModel
                //根据返回值 组装 真实的数据
                installDataForBasicInfo()
                
                callBackBlock(true,nil)
            } else {
                let error : YHErrorModel = YHErrorModel(errorCode:Int32(json.code),errorMsg: json.msg)
                callBackBlock(false,error)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
    
    //获取其他信息预览 数据
    func getPreviewForOtherInfo( params:[String : Any],callBackBlock:@escaping (_ success: Bool,_ error:YHErrorModel?)->()) {
        
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.Preview.previewOtherInfoApi
        let _ = YHNetRequest.getRequest(url: strUrl,params: params) { [weak self] json, code in
            //1. json字符串 转 对象
            guard let self = self else { return }
            
            if json.code == 200 {
                let dic = json.data
                guard let resultModel = YHPreviewForOtherInfoModel.deserialize(dict: dic as? [AnyHashable : Any]) else {
                    callBackBlock(false,nil)
                    return
                }
                
                self.otherInfoPreviewModel = resultModel
                
                installDataForOtherInfo()
                
                //根据返回值 组装 真实的数据
                callBackBlock(true,nil)
                
            } else {
                let err : YHErrorModel = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg)
                callBackBlock(false,err)
            }
        } failBlock: { err in
            callBackBlock(false,err)
        }
    }
    
}
private extension YHPreviewViewModel {
    
    //组装 主申请人预览 数据
    func installDataForMainApplicationInfo() {
        guard let model = mainApplicationInfoPreviewModel else { return  }
        
        do {
            //国家信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "国家/国籍：", answer: model.nationality)
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "港澳通行证：", answer: model.is_handled == 0 ? "未办理" : "已办理")
            let arr = [tmp0,tmp1]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "国籍信息", cellData0: arr)
            arrDataForMainApplicationInfo.append(model1)
        }
        
        do {
            //基本信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "主申请人：", answer: model.username)
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "曾用名：", answer: model.used_name)
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "婚前姓氏：", answer: model.surname)
            
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: model.birthday)
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: model.birth_place.area.description) //mainData.birth_place  for test hjl todo
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "性别：", answer: model.sex.description)//mainData.birth_place  for test hjl todo
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: model.married.description)//for test hjl todo
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "手机号：", answer: model.mobile)
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "邮箱：", answer: model.email)
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "现居住地址：", answer:model.live_address)
            
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "详细地址：", answer: model.live_address_detail)
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "是")//model.hk_id.has //for test hjl todo
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "香港身份证：", answer: "-")//model.hk_id.number //for test hjl todo
            
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7,tmp8,tmp9,tmp10,tmp11,tmp12]
            let model2 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "基本信息", cellData0: arr)
            arrDataForMainApplicationInfo.append(model2)
        }
        
        
        do {
            //证件信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "中国身份证号码：", answer: "2203381990287633390")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model0 = YHPersonInfoCellModel1(cellTitle: "中国身份证", cellData: [tmp0,tmp1,tmp2,tmp3])
            
            
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "旅行社证件号码：", answer: "c2345639")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model1 = YHPersonInfoCellModel1(cellTitle: "港澳通行证", cellData: [tmp4,tmp5,tmp6,tmp7])
            
            
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "证件类别：", answer: "护照")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "证件号码：", answer: "p2345639")
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2028-07-31")
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model2 = YHPersonInfoCellModel1(cellTitle: "护照及其他旅行证件", cellData: [tmp8,tmp9,tmp10,tmp11,tmp12])
            
            let arr = [model0,model1,model2]
            let model3 = YHPreviewInfoSessionModel(cellType: .idCardInfoType, cellTitle: "证件信息", cellData1: arr)
            arrDataForMainApplicationInfo.append(model3)
        }
        
        
        do {
            //证件照片
            let model1 = YHPersonInfoCellModel2(cellTitle: "中国身份证",frontUrl: "", backUrl: "", idType: 1)
            let model2 = YHPersonInfoCellModel2(cellTitle: "港澳通行证",frontUrl: "", backUrl: "", idType: 2)
            
            let arr = [model1,model2]
            let model4 = YHPreviewInfoSessionModel(cellType: .idPictureType, cellTitle: "证件照片", cellData2: arr)
            arrDataForMainApplicationInfo.append(model4)
        }
    }
    
    //组装 基本资料预览 数据
    func installDataForBasicInfo() {
        do {
            //主申请人
            if let model = basiceInfoPreviewModel?.applicant {
                let answer0 = model.has_conviction?.has == "Y" ? "是" : "否"
                let remark0 = answer0 == "是" ? (model.has_conviction?.info ?? "") : nil
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾在香港或其他地方因任何罪行或违法行为被被定罪：", answer: answer0,remark: remark0)
                
                
                let answer1 = model.has_departure?.has == "Y" ? "是" : "否"
                let remark1 = answer1 == "是" ? (model.has_conviction?.info ?? "") : nil
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾在香港或其他地方被拒入境/递解/遣送或要求离境？", answer: answer1,remark: remark1)
                
                
                let answer2 = model.has_deny?.has == "Y" ? "是" : "否"
                let remark2 = answer2 == "是" ? (model.has_deny?.info ?? "") : nil
                let tmp2 = YHPreviewQuestionAndAnswerModel(question: "3、是否曾被拒绝签发香港或其他地方的签证/进入许可？", answer: answer2,remark: remark2)
                
                
                let answer3 = model.has_breaking_law?.has == "Y" ? "是" : "否"
                let remark3 = answer3 == "是" ? (model.has_breaking_law?.info ?? "") : nil
                let tmp3 = YHPreviewQuestionAndAnswerModel(question: "4、是否曾触犯香港或任何地方的入境法例？", answer: answer3,remark:remark3)
                
                let answer4 = model.has_other_id?.has == "Y" ? "是" : "否"
                let remark4 = answer4 == "是" ? (model.has_other_id?.info ?? "") : nil
                let tmp4 = YHPreviewQuestionAndAnswerModel(question: "5、是否曾经使用另一个姓名或身份申请香港入境签证/进入许可或进入香港？", answer: answer4,remark: remark4)
                
                let arr = [tmp0,tmp1,tmp2,tmp3,tmp4]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "主申请人", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
        
        
        do {
            //子女 - xxx
            if let arrChild = basiceInfoPreviewModel?.child {
                for (index,model) in arrChild.enumerated() {
                    let answer0 = model.child_departure?.has == "Y" ? "是" : "否"
                    let remark0 = answer0 == "是" ? (model.child_departure?.info ?? "") : nil
                    
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾被拒绝入境/递解/遣送或要求离开香港？", answer: answer0,remark:remark0)
                    
                    
                    let answer1 = model.child_deny?.has == "Y" ? "是" : "否"
                    let remark1 = answer1 == "是" ? (model.child_deny?.info ?? "") : nil
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾被拒绝签发签证/进入许可以入境香港？", answer: answer1,remark: remark1)
                    let arr = [tmp0,tmp1]
                    
                    
                    let title = "子女" + "-" + model.subset_name
                    let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: title, cellData0: arr)
                    arrDataForBasicInfo.append(model1)
                }
            }
        }
        
        
        
        do {
            //配偶
            if let model = basiceInfoPreviewModel?.spouse {
                let answer0 = model.child_departure?.has == "Y" ? "是" : "否"
                let remark0 = answer0 == "是" ? (model.child_departure?.info ?? "") : nil
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、是否曾被拒绝入境/递解/遣送或要求离开香港？", answer: answer0,remark:remark0)
                
                let answer1 = model.child_deny?.has == "Y" ? "是" : "否"
                let remark1 = answer1 == "是" ? (model.child_deny?.info ?? "") : nil
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、是否曾被拒绝签发签证/进入许可以入境香港？", answer: answer1,remark: remark1)
                let arr = [tmp0,tmp1]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "配偶", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
        
        do {
            //家庭背景
            if let model = basiceInfoPreviewModel?.background {
                let answer0 = model.background_member?.has == "Y" ? "满足" : "不满足"
                let remark0 = answer0 == "满足" ? (model.background_member?.info ?? "") : nil
                
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、至少一名直系家庭成员（已婚配偶、父母、兄弟姐妹、子女）是现居于香港的香港永久性居民", answer:answer0,remark: remark0) //需要完善 for test hjl todo???
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "家庭背景", cellData0: arr)
                arrDataForBasicInfo.append(model1)
            }
        }
    }
    
    //组装 其他信息预览 数据
    func installDataForOtherInfo() {
        guard let model = otherInfoPreviewModel else {
            return
        }
        
        handleDataForOtherInfo()
        
        do {
            
            if let arr1 = model.list,arr1.isEmpty == false {
                var arr : [YHPersonInfoCellModel1] = []
                for (index,item) in arr1.enumerated() {
                    
                    //居住信息
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "开始时间：", answer: item.start_time)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "结束时间：", answer: item.end_time)
                    let title = "国家" + String(index + 1) + ":" + item.country
                    let model0 = YHPersonInfoCellModel1(cellTitle: title, cellData: [tmp0,tmp1])
                    
                    arr.append(model0)
                }
                
                let model3 = YHPreviewInfoSessionModel(cellType: .idCardInfoType, cellTitle: "居住信息", cellData1: arr)
                arrDataForOtherInfo.append(model3)
            }
        }
        
        
        do {
            //语言能力
            
            if let model = otherInfoPreviewModel?.language {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: model.levelDes, answer: model.remark)
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "语言能力", cellData0: arr)
                arrDataForOtherInfo.append(model1)
                
            }
        }
        
        do {
            //专业技能行业
            if let model = otherInfoPreviewModel?.profession {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、最能代表你的专业技能的行业是？（单选）", answer: model.optionDes,remark: model.remark)
                let arr = [tmp0]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "专业技能行业", cellData0: arr)
                arrDataForOtherInfo.append(model1)
            }
        }
        
        do {
            //其他问题
            if let model = otherInfoPreviewModel?.question {
                let tmp0 = YHPreviewQuestionAndAnswerModel(question: "1、您是否有行业内的专业资格证书？", answer: model.professional_qualification == 1 ? "是" : "否")
                let tmp1 = YHPreviewQuestionAndAnswerModel(question: "2、您是否在期刊或杂志上发表论文、文章、书籍等（与工作、资质有关的）？", answer: model.paper == 1 ? "是" : "否")
                let tmp2 = YHPreviewQuestionAndAnswerModel(question: "3、您是否有大学奖学金证明、专利证书、获奖证书（工作单位颁发的可以）？", answer: model.scholarship == 1 ? "是" : "否")
                let tmp3 = YHPreviewQuestionAndAnswerModel(question: "4、您是否被媒体采访过，专访您的文章被发表在杂志上或网络上？", answer: model.media_interview == 1 ? "是" : "否")
                let tmp4 = YHPreviewQuestionAndAnswerModel(question: "5、专业奖项：", answer: model.professional_awards)
                let tmp5 = YHPreviewQuestionAndAnswerModel(question: "6、学业奖项：", answer: model.academic_awards)
                let tmp6 = YHPreviewQuestionAndAnswerModel(question: "7、其他资料：", answer: model.other_information)
                let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6]
                let model1 = YHPreviewInfoSessionModel(cellType: .questionAndAnswer, cellTitle: "辅助资料", cellData0: arr)
                arrDataForOtherInfo.append(model1)
            }
        }
    }
}


private extension YHPreviewViewModel {
    //特殊处理 其他信息预览 需要的数据
    func handleDataForOtherInfo() {
        if let language = otherInfoPreviewModel?.language {
            if language.level > 0 {
                let target = String(language.level)
                for(_,item) in YHOtherInfoFillViewModel.arrLanguage.enumerated() {
                    
                    if target == item["id"] {
                        language.levelDes = item["title"] ?? "--"
                        language.remark = item["dec"] ?? "--"
                        break
                    }
                }
            }
        }
        
        
        
        if let profession = otherInfoPreviewModel?.profession {
            if profession.option > 0 {
                let target = String(profession.option)
                for(_,item) in YHOtherInfoFillViewModel.arrSkill.enumerated() {
                    
                    if target == item["value"] {
                        profession.optionDes = item["title"] ?? "--"
                        break
                    }
                }
            }
        }
    }
}


private extension YHPreviewViewModel {
    
    
    
    func installDataForFamilyInfo() {
        //父母
        installDataForParents()
//        return
        //配偶
        installDataForSpouse()
        //子女
        installDataForChildren()
        //兄弟姐妹
        installDataForBrother()
    }
    
    
    
    //父母 数据
    func installDataForParents() {
        do {
            if let model = familyInfoPreviewModel?.father {
                if model.deceased == 0 {
                    //父亲信息-健在
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "父亲姓名：", answer: model.subsetName)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "是否已故：", answer: "否")
                    let tmp2 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: model.birthday)
                    
                    var city = ""
                    if model.birthPlaceAboard == 0 {
                        //国内
                        if model.birthPlace.area.count > 1 {
                            city = "国内 " + model.birthPlace.area[0] + "/" + model.birthPlace.area[1]
                        } else {
                            city = "国内 --"
                        }
                    } else {
                        //国外
                        city = "国外 " + model.birthPlace.foreign
                    }
                    let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: city)
                    let tmp11 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: model.married)
                    
                    
                    let tmp4 = YHPreviewQuestionAndAnswerModel(question: "职业：", answer: model.occupation)
                    let tmp5 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: model.occupationName)
                    let tmp6 = YHPreviewQuestionAndAnswerModel(question: "现居住国家/地区：", answer: model.liveCountry)
                    let tmp7 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: model.hkIdentityCard == nil ? "否" : "是")
                    let tmp8 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: model.hkIdentityCard ?? "--")
                    
                    let arr = [tmp0,tmp1,tmp2,tmp3,tmp11,tmp4,tmp5,tmp6,tmp7,tmp8]
                    let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "父亲信息", cellData0: arr)
                    arrDataForParents.append(model1)
                    
                } else {
                    //父亲信息-已故
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "父亲姓名：", answer: model.subsetName)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "是否已故：", answer: "是")
                    let tmp2 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: model.birthday)
                    var city = ""
                    if model.birthPlaceAboard == 0 {
                        //国内
                        if model.birthPlace.area.count > 1 {
                            city = "国内 " + model.birthPlace.area[0] + "/" + model.birthPlace.area[1]
                        } else {
                            city = "国内 --"
                        }
                    } else {
                        //国外
                        city = "国外 " + model.birthPlace.foreign
                    }
                    let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: city)
                    let arr = [tmp0,tmp1,tmp2,tmp3]
                    let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "父亲信息", cellData0: arr)
                    arrDataForParents.append(model1)
                }
            } else {
                printLog("error:父亲数据不存在")
            }
        }
        
        
        do {
            if let model = familyInfoPreviewModel?.mother {
                if model.deceased == 0 {
                    //母亲信息-健在
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "母亲姓名：", answer: model.subsetName)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "是否已故：", answer: "否")
                    let tmp2 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: model.birthday)
                    var city = ""
                    if model.birthPlaceAboard == 0 {
                        //国内
                        if model.birthPlace.area.count > 1 {
                            city = "国内 " + model.birthPlace.area[0] + "/" + model.birthPlace.area[1]
                        } else {
                            city = "国内 --"
                        }
                    } else {
                        //国外
                        city = "国外 " + model.birthPlace.foreign
                    }
                    let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: city)
                    
                    let tmp11 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: model.married)
                    let tmp4 = YHPreviewQuestionAndAnswerModel(question: "职业：", answer: model.occupation)
                    let tmp5 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: model.occupationName)
                    let tmp6 = YHPreviewQuestionAndAnswerModel(question: "现居住国家/地区：", answer: model.liveCountry)
                    let tmp7 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: model.hkIdentityCard == nil ? "否" : "是")
                    let tmp8 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: model.hkIdentityCard ?? "--")
                    
                    let arr = [tmp0,tmp1,tmp11,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7,tmp8]
                    let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "母亲信息-健在", cellData0: arr)
                    arrDataForParents.append(model1)
                } else {
                    //母亲信息-已故
                    let tmp0 = YHPreviewQuestionAndAnswerModel(question: "母亲信息：", answer: model.subsetName)
                    let tmp1 = YHPreviewQuestionAndAnswerModel(question: "是否已故：", answer: "是")
                    let tmp2 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: model.birthday)
                    var city = ""
                    if model.birthPlaceAboard == 0 {
                        //国内
                        if model.birthPlace.area.count > 1 {
                            city = "国内 " + model.birthPlace.area[0] + "/" + model.birthPlace.area[1]
                        } else {
                            city = "国内 --"
                        }
                    } else {
                        //国外
                        city = "国外 " + model.birthPlace.foreign
                    }
                    let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: city)
                    let arr = [tmp0,tmp1,tmp2,tmp3]
                    let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "母亲信息-已故", cellData0: arr)
                    arrDataForParents.append(model1)
                }
            } else {
                printLog("error:母亲数据不存在")
            }
        }
        arrDataForFamilyInfo = arrDataForParents
    }
    
    //配偶 数据
    func installDataForSpouse() {
        do {
            //随行信息-否
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "是否随行至香港：", answer: "否")
            let arr = [tmp0]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "随行信息-否", cellData0: arr)
            arrDataForSpouse.append(model1)
        }
        
        do {
            //配偶信息-否
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "配偶姓名：", answer: "配偶姓名")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "曾用名：", answer: "曾用名：")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "婚前姓氏：", answer: "婚前姓氏：")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: "否")
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: "否")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "否")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: "否")
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "配偶信息-否", cellData0: arr)
            arrDataForSpouse.append(model1)
        }
        
        
        
        do {
            //随行信息 - 是
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "是否随行至香港：", answer: "否")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "国家/国籍：", answer: "中国-China")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "港澳通行证：", answer: "未办理")
            let arr = [tmp0,tmp1,tmp2]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "随行信息-否", cellData0: arr)
            arrDataForSpouse.append(model1)
        }
        
        
        do {
            //基本信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "配偶姓名：", answer: "DavidHuang")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "曾用名：", answer: "--")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "婚前姓氏：", answer: "--")
            
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: "1990年8月18日")
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: "国内 吉林省/吉林市")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "职业：", answer: "职业")
            
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: "职业名称")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "是否拥有学位：", answer: "是否拥有学位")
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "学位证：", answer: "学位证：")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "学位证颁发地区：", answer: "职业名称")
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "是否和主申请人同住：", answer: "职业名称")
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "现居住地址：", answer: "职业名称")
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "是否在海外居住满1年及以上：", answer: "职业名称")
            let tmp13 = YHPreviewQuestionAndAnswerModel(question: "目前是否在港：", answer: "职业名称")
            
            let tmp14 = YHPreviewQuestionAndAnswerModel(question: "获准逗留至：", answer: "职业名称")
            let tmp15 = YHPreviewQuestionAndAnswerModel(question: "在港身份：", answer: "职业名称")
            let tmp16 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "职业名称")
            let tmp17 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: "职业名称")
            
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7,tmp8,tmp9,tmp10,tmp11,tmp12,tmp13,tmp14,tmp15,tmp16,tmp17]
            let model2 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "基本信息", cellData0: arr)
            arrDataForSpouse.append(model2)
        }
        
        
        do {
            //证件信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "中国身份证号码：", answer: "2203381990287633390")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model0 = YHPersonInfoCellModel1(cellTitle: "中国身份证", cellData: [tmp0,tmp1,tmp2,tmp3])
            
            
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "旅行社证件号码：", answer: "c2345639")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model1 = YHPersonInfoCellModel1(cellTitle: "港澳通行证", cellData: [tmp4,tmp5,tmp6,tmp7])
            
            
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "证件类别：", answer: "护照")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "证件号码：", answer: "p2345639")
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2028-07-31")
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model2 = YHPersonInfoCellModel1(cellTitle: "护照及其他旅行证件", cellData: [tmp8,tmp9,tmp10,tmp11,tmp12])
            
            let arr = [model0,model1,model2]
            let model3 = YHPreviewInfoSessionModel(cellType: .idCardInfoType, cellTitle: "证件信息", cellData1: arr)
            arrDataForSpouse.append(model3)
        }
        
        
        do {
            //证件照片
            let model1 = YHPersonInfoCellModel2(cellTitle: "中国身份证",frontUrl: "", backUrl: "", idType: 1)
            let model2 = YHPersonInfoCellModel2(cellTitle: "港澳通行证",frontUrl: "", backUrl: "", idType: 2)
            
            let arr = [model1,model2]
            let model4 = YHPreviewInfoSessionModel(cellType: .idPictureType, cellTitle: "证件照片", cellData2: arr)
            arrDataForSpouse.append(model4)
        }
        
        arrDataForFamilyInfo = arrDataForSpouse
    }
    
    
    //子女 数据
    func installDataForChildren() {
        
        do {
            //随行信息-否
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "该子女是否随行至香港：", answer: "否")
            let arr = [tmp0]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "随行信息-否", cellData0: arr)
            arrDataForChildren.append(model1)
        }
        
        do {
            //子女信息-否
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "子女姓名：", answer: "子女姓名")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "曾用名：", answer: "曾用名：")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "婚前姓氏：", answer: "婚前姓氏：")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "性别：", answer: "性别")
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: "否")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: "否")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: "否")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: "否")
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "否")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: "否")
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7,tmp8,tmp9]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "子女信息-否", cellData0: arr)
            arrDataForChildren.append(model1)
        }
        
        do {
            //随行信息 - 是
            let tmp00 = YHPreviewQuestionAndAnswerModel(question: "主申请人或现配偶是否拥有孩子护养权：", answer: "否")
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "是否随行至香港：", answer: "否")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "国家/国籍：", answer: "中国-China")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "港澳通行证：", answer: "未办理")
            let arr = [tmp00,tmp0,tmp1,tmp2]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "随行信息-是", cellData0: arr)
            arrDataForChildren.append(model1)
        }
        
        do {
            //基本信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "子女姓名：", answer: "子女姓名")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "曾用名：", answer: "--")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "婚前姓氏：", answer: "--")
            
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: "1990年8月18日")
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: "国内 吉林省/吉林市")
            let tmp44 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: "婚姻状况")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "职业：", answer: "职业")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: "职业名称")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "是否拥有学位：", answer: "是否拥有学位")
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "学位证：", answer: "学位证：")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "学位证颁发地区：", answer: "职业名称")
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "是否和主申请人同住：", answer: "职业名称")
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "现居住地址：", answer: "职业名称")
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "是否在海外居住满1年及以上：", answer: "职业名称")
            let tmp122 = YHPreviewQuestionAndAnswerModel(question: "是否为前次婚姻的子女：", answer: "是否为前次婚姻的子女")
            let tmp13 = YHPreviewQuestionAndAnswerModel(question: "目前是否在港：", answer: "职业名称")
            let tmp14 = YHPreviewQuestionAndAnswerModel(question: "获准逗留至：", answer: "职业名称")
            let tmp15 = YHPreviewQuestionAndAnswerModel(question: "在港身份：", answer: "职业名称")
            let tmp16 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "职业名称")
            let tmp17 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: "p102987（1）")
            
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp44,tmp5,tmp6,tmp7,tmp8,tmp9,tmp10,tmp11,tmp12,tmp122,tmp13,tmp14,tmp15,tmp16,tmp17]
            let model2 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "基本信息", cellData0: arr)
            arrDataForChildren.append(model2)
        }
        
        
        do {
            //证件信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "中国身份证号码：", answer: "2203381990287633390")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model0 = YHPersonInfoCellModel1(cellTitle: "中国身份证", cellData: [tmp0,tmp1,tmp2,tmp3])
            
            
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "旅行社证件号码：", answer: "c2345639")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2018-07-17")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model1 = YHPersonInfoCellModel1(cellTitle: "港澳通行证", cellData: [tmp4,tmp5,tmp6,tmp7])
            
            
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "证件类别：", answer: "护照")
            let tmp9 = YHPreviewQuestionAndAnswerModel(question: "证件号码：", answer: "p2345639")
            let tmp10 = YHPreviewQuestionAndAnswerModel(question: "签发地：", answer: "北京市分局")
            let tmp11 = YHPreviewQuestionAndAnswerModel(question: "签发日期：", answer: "2028-07-31")
            let tmp12 = YHPreviewQuestionAndAnswerModel(question: "届满日期：", answer: "2028-07-31")
            let model2 = YHPersonInfoCellModel1(cellTitle: "护照及其他旅行证件", cellData: [tmp8,tmp9,tmp10,tmp11,tmp12])
            
            let arr = [model0,model1,model2]
            let model3 = YHPreviewInfoSessionModel(cellType: .idCardInfoType, cellTitle: "证件信息", cellData1: arr)
            arrDataForChildren.append(model3)
        }
        
        do {
            //证件照片
            let model1 = YHPersonInfoCellModel2(cellTitle: "中国身份证",frontUrl: "", backUrl: "", idType: 1)
            let model2 = YHPersonInfoCellModel2(cellTitle: "港澳通行证",frontUrl: "", backUrl: "", idType: 2)
            
            let arr = [model1,model2]
            let model4 = YHPreviewInfoSessionModel(cellType: .idPictureType, cellTitle: "证件照片", cellData2: arr)
            arrDataForChildren.append(model4)
        }
        arrDataForFamilyInfo = arrDataForChildren
    }
    
    
    
    //兄弟姐妹 数据
    func installDataForBrother() {
        do {
            //兄弟姐妹信息
            let tmp0 = YHPreviewQuestionAndAnswerModel(question: "姓名：", answer: "姓名")
            let tmp1 = YHPreviewQuestionAndAnswerModel(question: "婚姻状况：", answer: "未婚")
            let tmp2 = YHPreviewQuestionAndAnswerModel(question: "出生日期：", answer: "1990年8月18日")
            let tmp3 = YHPreviewQuestionAndAnswerModel(question: "出生城市：", answer: "国内 吉林省/吉林市")
            
            let tmp4 = YHPreviewQuestionAndAnswerModel(question: "职业：", answer: "在职")
            let tmp5 = YHPreviewQuestionAndAnswerModel(question: "职业名称：", answer: "设计师")
            let tmp6 = YHPreviewQuestionAndAnswerModel(question: "现居住国家/地区：", answer: "国内 吉林省/吉林市")
            let tmp7 = YHPreviewQuestionAndAnswerModel(question: "是否办理过香港身份证：", answer: "国内 吉林省/吉林市")
            let tmp8 = YHPreviewQuestionAndAnswerModel(question: "香港身份证号码：", answer: "p102987（1）")
            
            let arr = [tmp0,tmp1,tmp2,tmp3,tmp4,tmp5,tmp6,tmp7,tmp8]
            let model1 = YHPreviewInfoSessionModel(cellType: .countryInfoType, cellTitle: "兄弟姐妹信息", cellData0: arr)
            arrDataForBrother.append(model1)
        }
        arrDataForFamilyInfo = arrDataForBrother
    }
}
